Check if the app is running in a bundled (standalone) environment
Source:R/utils.R
rdesk_is_bundle.RdCheck if the app is running in a bundled (standalone) environment

R/utils.R
rdesk_is_bundle.RdCheck if the app is running in a bundled (standalone) environment